@@ -14,6 +14,7 @@
 # MDAnalysis: A Python package for the rapid analysis of molecular dynamics
 # simulations. In S. Benthall and S. Rostrup editors, Proceedings of the 15th
 # Python in Science Conference, pages 102-109, Austin, TX, 2016. SciPy.
+# doi: 10.25080/majora-629e541a-00e
 #
 # N. Michaud-Agrawal, E. J. Denning, T. B. Woolf, and O. Beckstein.
 # MDAnalysis: A Toolkit for the Analysis of Molecular Dynamics Simulations.
@@ -212,8 +213,9 @@ class AuxStep(object):
         try:
             select = self._select_data
         except AttributeError:
-                warnings.warn("{} does not support data selection".format(
-                                                      self.__class__.__name__))
+            warnings.warn(
+                "{} does not support data selection".format(self.__class__.__name__)
+            )
         else:
             # check *new* is valid before setting; _select_data should raise an
             # error if not
@@ -418,9 +420,13 @@ class AuxReader(six.with_metaclass(_AuxReaderMeta)):
         # following frame. Move to right position if not.
         frame_for_step = self.step_to_frame(self.step, ts)
         frame_for_next_step = self.step_to_frame(self.step+1, ts)
-        if (frame_for_step is not None and frame_for_next_step is not None
-                and not (frame_for_step < ts.frame <= frame_for_next_step)):
-            self.move_to_ts(ts)
+        if frame_for_step is not None:
+            if frame_for_next_step is None:
+                # self.step is the last auxiliary step in memory.
+                if frame_for_step >= ts.frame:
+                    self.move_to_ts(ts)
+            elif not (frame_for_step < ts.frame <= frame_for_next_step):
+                self.move_to_ts(ts)
 
         self._reset_frame_data() # clear previous frame data
         # read through all the steps 'assigned' to ts.frame + add to frame_data
@@ -477,7 +483,7 @@ class AuxReader(six.with_metaclass(_AuxReaderMeta)):
             return frame_index
         else:
             time_frame = time_frame_0 + frame_index*ts.dt
-            time_diff = abs(time_frame_0 - time_step)
+            time_diff = abs(time_frame - time_step)
             return frame_index, time_diff
 
     def move_to_ts(self, ts):
@@ -596,7 +602,7 @@ class AuxReader(six.with_metaclass(_AuxReaderMeta)):
 
     def _check_index(self, i):
         if not isinstance(i, numbers.Integral):
-                raise TypeError("Step indices must be integers")
+            raise TypeError("Step indices must be integers")
         if i < 0:
             i = i + self.n_steps
         if i < 0 or i >= self.n_steps:
@@ -823,7 +829,7 @@ class AuxReader(six.with_metaclass(_AuxReaderMeta)):
 
     @time_selector.setter
     def time_selector(self, new):
-        olf = self.auxstep._time_selector
+        old = self.auxstep._time_selector
         self.auxstep._time_selector = new
         if old != new:
             # if constant_dt is False and so we're using a _times list, this will
@@ -907,7 +913,7 @@ class AuxFileReader(AuxReader):
 
     def _reopen(self):
         """ Close and then reopen *auxfile*. """
-        if self.auxfile != None:
+        if self.auxfile is not None:
             self.auxfile.close()
         self.auxfile = open(self._auxdata)
         self.auxstep.step = -1
