@@ -14,6 +14,7 @@
 # MDAnalysis: A Python package for the rapid analysis of molecular dynamics
 # simulations. In S. Benthall and S. Rostrup editors, Proceedings of the 15th
 # Python in Science Conference, pages 102-109, Austin, TX, 2016. SciPy.
+# doi: 10.25080/majora-629e541a-00e
 #
 # N. Michaud-Agrawal, E. J. Denning, T. B. Woolf, and O. Beckstein.
 # MDAnalysis: A Toolkit for the Analysis of Molecular Dynamics Simulations.
@@ -142,9 +143,8 @@ Classes
 from __future__ import absolute_import
 
 from six.moves import range, zip
-from six import StringIO, BytesIO
+from six import raise_from, StringIO, BytesIO
 
-import io
 import os
 import errno
 import itertools
@@ -154,11 +154,9 @@ import logging
 import collections
 import numpy as np
 
-from ..core import flags
 from ..lib import util
 from . import base
 from ..topology.core import guess_atom_element
-from ..core.universe import Universe
 from ..exceptions import NoDataError
 
 
@@ -167,6 +165,7 @@ logger = logging.getLogger("MDAnalysis.coordinates.PBD")
 # Pairs of residue name / atom name in use to deduce PDB formatted atom names
 Pair = collections.namedtuple('Atom', 'resname name')
 
+
 class PDBReader(base.ReaderBase):
     """PDBReader that reads a `PDB-formatted`_ file, no frills.
 
@@ -217,20 +216,34 @@ class PDBReader(base.ReaderBase):
     79 - 80        LString(2)    charge       Charge  on the atom.
     =============  ============  ===========  =============================================
 
+    Notes
+    -----
+    If a system does not have unit cell parameters (such as in electron
+    microscopy structures), the PDB file format requires the CRYST1_ field to
+    be provided with unitary values (cubic box with sides of 1 Å) and an
+    appropriate REMARK. If unitary values are found within the CRYST1_ field,
+    :code:`PDBReader` will not set unit cell dimensions (which will take the
+    default value :code:`np.zeros(6)`, see Issue #2698)
+    and it will warn the user.
+
+    .. _CRYST1: http://www.wwpdb.org/documentation/file-format-content/format33/sect8.html#CRYST1
+
 
     See Also
     --------
     :class:`PDBWriter`
     :class:`PDBReader`
-       implements a larger subset of the header records,
-       which are accessible as :attr:`PDBReader.metadata`.
-
 
     .. versionchanged:: 0.11.0
        * Frames now 0-based instead of 1-based
        * New :attr:`title` (list with all TITLE lines).
     .. versionchanged:: 0.19.1
        Can now read PDB files with DOS line endings
+    .. versionchanged:: 0.20.0
+       Strip trajectory header of trailing spaces and newlines
+    .. versionchanged:: 1.0.0
+       Raise user warning for CRYST1_ record with unitary valuse
+       (cubic box with sides of 1 Å) and do not set cell dimensions.
     """
     format = ['PDB', 'ENT']
     units = {'time': None, 'length': 'Angstrom'}
@@ -258,11 +271,11 @@ class PDBReader(base.ReaderBase):
             self.n_atoms = top.n_atoms
 
         self.model_offset = kwargs.pop("model_offset", 0)
-
-        self.header = header = ""
-        self.title = title = []
-        self.compound = compound = []
-        self.remarks = remarks = []
+        # dummy/default variables as these are read
+        header = ""
+        title = []
+        compound = []
+        remarks = []
 
         self.ts = self._Timestep(self.n_atoms, **self._ts_kwargs)
 
@@ -296,7 +309,7 @@ class PDBReader(base.ReaderBase):
                 # classification = line[10:50]
                 # date = line[50:59]
                 # idCode = line[62:66]
-                header = line[10:66].decode()
+                header = line[10:66].strip().decode()
             elif line[:5] == b'TITLE':
                 title.append(line[8:80].strip().decode())
             elif line[:6] == b'COMPND':
@@ -306,6 +319,11 @@ class PDBReader(base.ReaderBase):
 
         end = pdbfile.tell()  # where the file ends
 
+        self.header = header
+        self.title = title
+        self.compound = compound
+        self.remarks = remarks
+
         if not models:
             # No model entries
             # so read from start of file to read first frame
@@ -358,11 +376,25 @@ class PDBReader(base.ReaderBase):
         return self._read_frame(frame)
 
     def _read_frame(self, frame):
+        """
+        Read frame from PDB file.
+
+        Notes
+        -----
+        When the CRYST1_ record has unitary values (cubic box with sides of
+        1 Å), cell dimensions are considered fictitious. An user warning is
+        raised and cell dimensions are set to
+        :code:`np.zeros(6)` (see Issue #2698)
+
+        .. versionchanged:: 1.0.0
+           Raise user warning for CRYST1_ record with unitary valuse
+           (cubic box with sides of 1 Å) and do not set cell dimensions.
+        """
         try:
             start = self._start_offsets[frame]
             stop = self._stop_offsets[frame]
         except IndexError:  # out of range of known frames
-            raise IOError
+            raise_from(IOError, None)
 
         pos = 0
         occupancy = np.ones(self.n_atoms)
@@ -386,18 +418,37 @@ class PDBReader(base.ReaderBase):
                 pos += 1
             elif line[:6] == 'CRYST1':
                 # does an implicit str -> float conversion
-                self.ts._unitcell[:] = [line[6:15], line[15:24],
-                                        line[24:33], line[33:40],
-                                        line[40:47], line[47:54]]
-
-        # doing the conversion from list to array at the end is faster
-        self.ts.positions = tmp_buf
+                try:
+                    cell_dims = np.array([line[6:15], line[15:24],
+                                         line[24:33], line[33:40],
+                                         line[40:47], line[47:54]],
+                                         dtype=np.float32)
+                except ValueError:
+                    warnings.warn("Failed to read CRYST1 record, "
+                                  "possibly invalid PDB file, got:\n{}"
+                                  "".format(line))
+                else:
+                    if np.allclose(cell_dims, np.array([1.0, 1.0, 1.0, 90.0, 90.0, 90.0])):
+                        # FIXME: Dimensions set to zeros.
+                        # FIXME: This might change with Issue #2698
+                        warnings.warn("1 A^3 CRYST1 record,"
+                                      " this is usually a placeholder."
+                                      " Unit cell dimensions will be set"
+                                      " to zeros.")
+                    else:
+                        self.ts._unitcell[:] = cell_dims
 
         # check if atom number changed
         if pos != self.n_atoms:
-            raise ValueError("Read an incorrect number of atoms\n"
-                             "Expected {expected} got {actual}"
-                             "".format(expected=self.n_atoms, actual=pos+1))
+            raise ValueError("Inconsistency in file '{}': The number of atoms "
+                             "({}) in trajectory frame {} differs from the "
+                             "number of atoms ({}) in the corresponding "
+                             "topology.\nTrajectories with varying numbers of "
+                             "atoms are currently not supported."
+                             "".format(self.filename, pos, frame, self.n_atoms))
+
+        # doing the conversion from list to array at the end is faster
+        self.ts.positions = tmp_buf
 
         if self.convert_units:
             # both happen inplace
@@ -441,6 +492,10 @@ class PDBWriter(base.WriterBase):
     The maximum frame number that can be stored in a PDB file is 9999 and it
     will wrap around (see :meth:`MODEL` for further details).
 
+    The CRYST1_ record specifies the unit cell. This record is set to
+    unitary values (cubic box with sides of 1 Å) if unit cell dimensions
+    are not set (:code:`None` or :code:`np.zeros(6)`,
+    see Issue #2698).
 
     See Also
     --------
@@ -463,6 +518,13 @@ class PDBWriter(base.WriterBase):
     .. versionchanged:: 0.14.0
        PDB doesn't save charge information
 
+    .. versionchanged:: 0.20.0
+       Strip trajectory header of trailing spaces and newlines
+
+    .. versionchanged:: 1.0.0
+       ChainID now comes from the last character of segid, as stated in the documentation.
+       An indexing issue meant it previously used the first charater (Issue #2224)
+
     """
     fmt = {
         'ATOM': (
@@ -521,7 +583,7 @@ class PDBWriter(base.WriterBase):
 
     def __init__(self, filename, bonds="conect", n_atoms=None, start=0, step=1,
                  remarks="Created by PDBWriter",
-                 convert_units=None, multiframe=None):
+                 convert_units=True, multiframe=None):
         """Create a new PDBWriter
 
         Parameters
@@ -538,9 +600,8 @@ class PDBWriter(base.WriterBase):
            any remarks from the trajectory that serves as input are
            written to REMARK records with lines longer than :attr:`remark_max_length` (66
            characters) being wrapped.
-        convert_units: str (optional)
-           units are converted to the MDAnalysis base format; ``None`` selects
-           the value of :data:`MDAnalysis.core.flags` ['convert_lengths']
+        convert_units: bool (optional)
+           units are converted to the MDAnalysis base format; [``True``]
         bonds : {"conect", "all", None} (optional)
            If set to "conect", then only write those bonds that were already
            defined in an input PDB file as PDB CONECT_ record. If set to "all",
@@ -551,7 +612,6 @@ class PDBWriter(base.WriterBase):
            multi frame PDB file in which frames are written as MODEL_ ... ENDMDL_
            records. If ``None``, then the class default is chosen.    [``None``]
 
-
         .. _CONECT: http://www.wwpdb.org/documentation/file-format-content/format32/sect10.html#CONECT
         .. _MODEL: http://www.wwpdb.org/documentation/file-format-content/format32/sect9.html#MODEL
         .. _ENDMDL: http://www.wwpdb.org/documentation/file-format-content/format32/sect9.html#ENDMDL
@@ -564,8 +624,6 @@ class PDBWriter(base.WriterBase):
         #       - additional title keyword could contain line for TITLE
 
         self.filename = filename
-        if convert_units is None:
-            convert_units = flags['convert_lengths']
         # convert length and time to base units
         self.convert_units = convert_units
         self._multiframe = self.multiframe if multiframe is None else multiframe
@@ -574,7 +632,7 @@ class PDBWriter(base.WriterBase):
         if start < 0:
             raise ValueError("'Start' must be a positive value")
 
-        self.start =  self.frames_written = start
+        self.start = self.frames_written = start
         self.step = step
         self.remarks = remarks
 
@@ -602,7 +660,28 @@ class PDBWriter(base.WriterBase):
                        "".format(self.start, self.remarks))
 
     def _write_pdb_header(self):
-        if self.first_frame_done == True:
+        """
+        Write PDB header.
+
+        The HEADER_ record is set to :code: `trajectory.header`.
+        The TITLE_ record explicitly mentions MDAnalysis and contains
+        information about trajectory frame(s).
+        The COMPND_ record is set to :code:`trajectory.compound`.
+        The REMARKS_ records are set to :code:`u.trajectory.remarks`
+        The CRYST1_ record specifies the unit cell. This record is set to
+        unitary values (cubic box with sides of 1 Å) if unit cell dimensions
+        are not set.
+
+        .. _COMPND: http://www.wwpdb.org/documentation/file-format-content/format33/sect2.html#COMPND
+        .. _REMARKS: http://www.wwpdb.org/documentation/file-format-content/format33/remarks.html
+
+        .. versionchanged: 1.0.0
+           Fix writing of PDB file without unit cell dimensions (Issue #2679).
+           If cell dimensions are not found, unitary values (cubic box with
+           sides of 1 Å) are used (PDB standard for CRYST1_).
+        """
+
+        if self.first_frame_done is True:
             return
 
         self.first_frame_done = True
@@ -622,7 +701,29 @@ class PDBWriter(base.WriterBase):
             self.REMARK(*remarks)
         except AttributeError:
             pass
-        self.CRYST1(self.convert_dimensions_to_unitcell(u.trajectory.ts))
+
+        # FIXME: Values for meaningless cell dimensions are not consistent.
+        # FIXME: See Issue #2698. Here we check for both None and zeros
+        if u.dimensions is None or np.allclose(u.dimensions, np.zeros(6)):
+            # Unitary unit cell by default. See PDB standard:
+            # http://www.wwpdb.org/documentation/file-format-content/format33/sect8.html#CRYST1
+            self.CRYST1(np.array([1.0, 1.0, 1.0, 90.0, 90.0, 90.0]))
+
+            # Add CRYST1 REMARK (285)
+            # The SCALE record is not included
+            # (We are only implementing a subset of the PDB standard)
+            self.REMARK("285 UNITARY VALUES FOR THE UNIT CELL AUTOMATICALLY SET")
+            self.REMARK("285 BY MDANALYSIS PDBWRITER BECAUSE UNIT CELL INFORMATION")
+            self.REMARK("285 WAS MISSING.")
+            self.REMARK("285 PROTEIN DATA BANK CONVENTIONS REQUIRE THAT")
+            self.REMARK("285 CRYST1 RECORD IS INCLUDED, BUT THE VALUES ON")
+            self.REMARK("285 THIS RECORD ARE MEANINGLESS.")
+
+            warnings.warn("Unit cell dimensions not found. "
+                          "CRYST1 record set to unitary values.")
+
+        else:
+            self.CRYST1(self.convert_dimensions_to_unitcell(u.trajectory.ts))
 
     def _check_pdb_coordinates(self):
         """Check if the coordinate values fall within the range allowed for PDB files.
@@ -631,7 +732,14 @@ class PDBWriter(base.WriterBase):
         already been written (in multi-frame mode) adds a REMARK instead of the
         coordinates and closes the file.
 
-        Raises :exc:`ValueError` if the coordinates fail the check.
+        Raises
+        ------
+        ValueError
+            if the coordinates fail the check.
+
+        .. versionchanged: 1.0.0
+            Check if :attr:`filename` is `StringIO` when attempting to remove
+            a PDB file with invalid coordinates (Issue #2512)
         """
         atoms = self.obj.atoms  # make sure to use atoms (Issue 46)
         # can write from selection == Universe (Issue 49)
@@ -657,6 +765,14 @@ class PDBWriter(base.WriterBase):
             except OSError as err:
                 if err.errno == errno.ENOENT:
                     pass
+                else:
+                    raise
+            except TypeError:
+                if isinstance(self.filename, StringIO):
+                    pass
+                else:
+                    raise
+
         raise ValueError("PDB files must have coordinate values between "
                          "{0:.3f} and {1:.3f} Angstroem: file writing was "
                          "aborted.".format(self.pdb_coor_limits["min"],
@@ -670,12 +786,11 @@ class PDBWriter(base.WriterBase):
         if not self.obj or not hasattr(self.obj.universe, 'bonds'):
             return
 
-        bondset = set(itertools.chain(*(a.bonds for a in self.obj.atoms)))
-
         mapping = {index: i for i, index in enumerate(self.obj.atoms.indices)}
 
-        # Write out only the bonds that were defined in CONECT records
+        bondset = set(itertools.chain(*(a.bonds for a in self.obj.atoms)))
         if self.bonds == "conect":
+            # Write out only the bonds that were defined in CONECT records
             bonds = ((bond[0].index, bond[1].index) for bond in bondset if not bond.is_guessed)
         elif self.bonds == "all":
             bonds = ((bond[0].index, bond[1].index) for bond in bondset)
@@ -691,9 +806,8 @@ class PDBWriter(base.WriterBase):
 
         atoms = np.sort(self.obj.atoms.indices)
 
-        conect = ([a] + sorted(con[a])
+        conect = ([mapping[a]] + sorted([mapping[at] for at in con[a]])
                   for a in atoms if a in con)
-        connect = ([mapping[x] for x in row] for row in conect)
 
         for c in conect:
             self.CONECT(c)
@@ -711,7 +825,7 @@ class PDBWriter(base.WriterBase):
         * :attr:`PDBWriter.timestep` (the underlying trajectory
           :class:`~MDAnalysis.coordinates.base.Timestep`)
 
-        Before calling :meth:`write_next_timestep` this method **must** be
+        Before calling :meth:`_write_next_frame` this method **must** be
         called at least once to enable extracting topology information from the
         current frame.
         """
@@ -750,7 +864,7 @@ class PDBWriter(base.WriterBase):
         # Issue 105: with write() ONLY write a single frame; use
         # write_all_timesteps() to dump everything in one go, or do the
         # traditional loop over frames
-        self.write_next_timestep(self.ts, multiframe=self._multiframe)
+        self._write_next_frame(self.ts, multiframe=self._multiframe)
         self._write_pdb_bonds()
         # END record is written when file is being close()d
 
@@ -793,7 +907,7 @@ class PDBWriter(base.WriterBase):
 
         for framenumber in range(start, len(traj), step):
             traj[framenumber]
-            self.write_next_timestep(self.ts, multiframe=True)
+            self._write_next_frame(self.ts, multiframe=True)
 
         self._write_pdb_bonds()
         self.close()
@@ -801,7 +915,7 @@ class PDBWriter(base.WriterBase):
         # Set the trajectory to the starting position
         traj[start]
 
-    def write_next_timestep(self, ts=None, **kwargs):
+    def _write_next_frame(self, ts=None, **kwargs):
         '''write a new timestep to the PDB file
 
         :Keywords:
@@ -817,13 +931,21 @@ class PDBWriter(base.WriterBase):
            argument, :meth:`PDBWriter._update_frame` *must* be called
            with the :class:`~MDAnalysis.core.groups.AtomGroup.Universe` as
            its argument so that topology information can be gathered.
+
+
+        .. versionchanged:: 1.0.0
+           Renamed from `write_next_timestep` to `_write_next_frame`.
         '''
         if ts is None:
             try:
                 ts = self.ts
             except AttributeError:
-                raise NoDataError("PBDWriter: no coordinate data to write to "
-                                  "trajectory file")
+                raise_from(
+                    NoDataError(
+                        "PBDWriter: no coordinate data to write to "
+                        "trajectory file"
+                        ),
+                    None)
         self._check_pdb_coordinates()
         self._write_timestep(ts, **kwargs)
 
@@ -876,6 +998,10 @@ class PDBWriter(base.WriterBase):
            underlying trajectory and only if ``len(traj) > 1`` would MODEL records
            have been written.)
 
+        .. versionchanged:: 1.0.0
+           ChainID now comes from the last character of segid, as stated in the documentation.
+           An indexing issue meant it previously used the first charater (Issue #2224)
+
         """
         atoms = self.obj.atoms
         pos = atoms.positions
@@ -916,7 +1042,7 @@ class PDBWriter(base.WriterBase):
             vals['name'] = self._deduce_PDB_atom_name(atomnames[i], resnames[i])
             vals['altLoc'] = altlocs[i][:1]
             vals['resName'] = resnames[i][:4]
-            vals['chainID'] = segids[i][:1]
+            vals['chainID'] = segids[i][-1:]
             vals['resSeq'] = util.ltruncate_int(resids[i], 4)
             vals['iCode'] = icodes[i][:1]
             vals['pos'] = pos[i]  # don't take off atom so conversion works
@@ -936,10 +1062,13 @@ class PDBWriter(base.WriterBase):
 
         .. _HEADER: http://www.wwpdb.org/documentation/file-format-content/format32/sect2.html#HEADER
 
+        .. versionchanged:: 0.20.0
+            Strip `trajectory.header` since it can be modified by the user and should be
+            sanitized (Issue #2324)
         """
         if not hasattr(trajectory, 'header'):
             return
-        header = trajectory.header
+        header = trajectory.header.strip()
         self.pdbfile.write(self.fmt['HEADER'].format(header))
 
     def TITLE(self, *title):
@@ -975,9 +1104,6 @@ class PDBWriter(base.WriterBase):
 
     def CRYST1(self, dimensions, spacegroup='P 1', zvalue=1):
         """Write CRYST1_ record.
-
-        .. _CRYST1: http://www.wwpdb.org/documentation/file-format-content/format32/sect8.html#CRYST1
-
         """
         self.pdbfile.write(self.fmt['CRYST1'].format(
             box=dimensions[:3],
