@@ -113,6 +113,9 @@ def make_downshift_arrays(upshift, nparents):
     .. warning:: This means negative indexing should **never**
                  be used with these arrays.
     """
+    if not len(upshift):
+        return np.array([], dtype=object)
+        
     order = np.argsort(upshift)
 
     upshift_sorted = upshift[order]
@@ -580,3 +583,4 @@ class Topology(object):
             attr.values = np.concatenate([attr.values, np.array([newval])])
 
         return segidx
+        
\ No newline at end of file
