@@ -45,6 +45,7 @@ exception of `:func:get_writer`:
 .. autofunction:: get_writer
 """
 from __future__ import absolute_import
+from six import raise_from
 
 import os.path
 
@@ -85,6 +86,7 @@ def get_writer(filename, defaultformat):
     try:
         return _SELECTION_WRITERS[format]
     except KeyError:
-        raise NotImplementedError(
+        raise_from(NotImplementedError(
             "Writing as {0!r} is not implemented;"
-            " only {1!r} will work.".format(format, _SELECTION_WRITERS.keys()))
+            " only {1!r} will work.".format(format, _SELECTION_WRITERS.keys())),
+            None)
