@@ -14,6 +14,7 @@
 # MDAnalysis: A Python package for the rapid analysis of molecular dynamics
 # simulations. In S. Benthall and S. Rostrup editors, Proceedings of the 15th
 # Python in Science Conference, pages 102-109, Austin, TX, 2016. SciPy.
+# doi: 10.25080/majora-629e541a-00e
 #
 # N. Michaud-Agrawal, E. J. Denning, T. B. Woolf, and O. Beckstein.
 # MDAnalysis: A Toolkit for the Analysis of Molecular Dynamics Simulations.
@@ -68,6 +69,7 @@ from ..core.topologyattrs import (
     AltLocs,
     Atomtypes,
     Charges,
+    ICodes,
     Masses,
     Occupancies,
     RecordTypes,
@@ -171,6 +173,7 @@ class PDBQTParser(TopologyReaderBase):
         n_residues = len(resids)
         attrs.append(Resids(resids))
         attrs.append(Resnums(resids.copy()))
+        attrs.append(ICodes(icodes))
         attrs.append(Resnames(resnames))
 
         segidx, (segids,) = change_squash((chainids,), (chainids,))
