@@ -50,6 +50,8 @@ from __future__ import absolute_import
 
 from six.moves import range
 import numpy as np
+import xdrlib
+import struct
 
 from . import obj
 from . import setting as S
@@ -73,18 +75,119 @@ from ...core.topologyattrs import (
 )
 
 
-
-def do_string(data):
-    """Emulate gmx_fio_do_string
-
-    gmx_fio_do_string reads a string from a XDR file. On the contraty to the
-    python unpack_string, gmx_fio_do_string reads the size as an unsigned
-    interger before reading the actual string.
-
-    See <gromacs-2016-src>/src/gromacs/fileio/gmx_system_xdr.c:454
+class TPXUnpacker(xdrlib.Unpacker):
     """
-    data.unpack_int()
-    return data.unpack_string()
+    Extend the standard XDR unpacker for the specificity of TPX files.
+    """
+    def __init__(self, data):
+        # Using super here would be ideal, but it does not work on python2 as
+        # TPXUnpacker is a `classobj` and not a `type`.
+        # super().__init__(data)
+        xdrlib.Unpacker.__init__(self, data)
+        self._buf = self.get_buffer()
+
+    # The parent class uses a dunder attribute to store the
+    # cursor position. This property makes it easier to manipulate
+    # this attribute that is otherwise "protected".
+    # The use of this property works well in python3, but fails in python2
+    # where direct access to the mangled attribute seems required.
+    @property
+    def _pos(self):
+        return self.get_position()
+
+    @_pos.setter
+    def _pos(self, value):
+        self.set_position(value)
+
+    def _unpack_value(self, item_size, struct_template):
+        # Ideally, we should use the _pos attribute, but it present some
+        # unexpected behaviour on python2 where the position of the cursor is
+        # not kept in sync between the method defined in TPXUnpacker and the
+        # methods defined in the base class.
+        # start_position = self._pos
+        # end_position = self._pos = start_position + item_size
+        start_position = self._Unpacker__pos  # pylint: disable=access-member-before-definition 
+        end_position = self._pos = self._Unpacker__pos = start_position + item_size
+        content = self._buf[start_position:end_position]
+        if len(content) != item_size:
+            raise EOFError
+        return struct.unpack(struct_template, content)[0]
+
+    def unpack_int64(self):
+        return self._unpack_value(8, '>q')
+
+    def unpack_uint64(self):
+        return self._unpack_value(8, '>Q')
+
+    def unpack_ushort(self):
+        return self.unpack_uint()
+
+    def unpack_uchar(self):
+        # TPX files prior to gromacs 2020 (tpx version < 119) use unsigned ints
+        # (4 bytes) instead of unsigned chars.
+        return self._unpack_value(4, '>I')
+
+    def do_string(self):
+        """
+        Emulate gmx_fio_do_string
+
+        gmx_fio_do_string reads a string from a XDR file. On the contrary to the
+        python unpack_string, gmx_fio_do_string reads the size as an unsigned
+        integer before reading the actual string.
+
+        See <gromacs-2016-src>/src/gromacs/fileio/gmx_system_xdr.c:454
+        """
+        self.unpack_int()
+        return self.unpack_string()
+
+
+class TPXUnpacker2020(TPXUnpacker):
+    """
+    Unpacker for TPX files from and later than gromacs 2020.
+
+    A new implementation of the serializer (InMemorySerializer), introduced in
+    gromacs 2020, changes le meaning of some types in the file body (the header
+    keep using the previous implementation of the serializer).
+    """
+    @classmethod
+    def from_unpacker(cls, unpacker):
+        new_unpacker = cls(unpacker._buf)
+        new_unpacker._pos = new_unpacker._Unpacker__pos = unpacker._Unpacker__pos
+        if hasattr(unpacker, 'unpack_real'):
+            if unpacker.unpack_real == unpacker.unpack_float:
+                new_unpacker.unpack_real = new_unpacker.unpack_float
+            elif unpacker.unpack_real == unpacker.unpack_double:
+                new_unpacker.unpack_real = new_unpacker.unpack_double
+            else:
+                raise ValueError("Unrecognized precision")
+        return new_unpacker
+
+    def unpack_fstring(self, n):
+        if n < 0:
+            raise ValueError('Size of fstring cannot be negative.')
+        start_position = self._Unpacker__pos # pylint: disable=access-member-before-definition
+        end_position = self._pos = self._Unpacker__pos = start_position + n
+        if end_position > len(self._buf):
+            raise EOFError
+        content = self._buf[start_position:end_position]
+        return content
+
+    def unpack_ushort(self):
+        # The InMemorySerializer implements ushort according to the XDR standard
+        # on the contrary to the IO serializer.
+        return self._unpack_value(2, '>H')
+
+    def unpack_uchar(self):
+        # The InMemorySerializer implements uchar according to the XDR standard
+        # on the contrary to the IO serializer.
+        return self._unpack_value(1, '>B')
+
+    def do_string(self):
+        """
+        Emulate gmx_fio_do_string
+        """
+        n = self.unpack_uint64()
+        return self.unpack_fstring(n)
 
 
 def ndo_int(data, n):
@@ -132,7 +235,7 @@ def read_tpxheader(data):
     """this function is now compatible with do_tpxheader in tpxio.cpp
     """
     # Last compatibility check with gromacs-2016
-    ver_str = do_string(data)  # version string e.g. VERSION 4.0.5
+    ver_str = data.do_string()  # version string e.g. VERSION 4.0.5
     precision = data.unpack_int()  # e.g. 4
     define_unpack_real(precision, data)
     fileVersion = data.unpack_int()  # version of tpx file
@@ -142,7 +245,7 @@ def read_tpxheader(data):
     # the tag was, mistakenly, placed before the generation.
     if 77 <= fileVersion <= 79:
         data.unpack_int()  # the value is 8, but haven't found the
-        file_tag = do_string(data)
+        file_tag = data.do_string()
 
     fileGeneration = data.unpack_int() if fileVersion >= 26 else 0  # generation of tpx file, e.g. 17
 
@@ -151,7 +254,7 @@ def read_tpxheader(data):
     # tpx_tag from a lower or the same version of gromacs code can be parsed by
     # the tpxio.c
 
-    file_tag = do_string(data) if fileVersion >= 81 else S.TPX_TAG_RELEASE
+    file_tag = data.do_string() if fileVersion >= 81 else S.TPX_TAG_RELEASE
 
     natoms = data.unpack_int()  # total number of atoms
     ngtc = data.unpack_int() if fileVersion >= 28 else 0  # number of groups for T-coupling
@@ -164,7 +267,7 @@ def read_tpxheader(data):
     fep_state = data.unpack_int() if fileVersion >= 79 else 0
 
     # actually, it's lambda, not sure what is it. us lamb because lambda is a
-    # keywod in python
+    # keyword in python
     lamb = data.unpack_real()
     bIr = data.unpack_int()  # has input record or not
     bTop = data.unpack_int()  # has topology or not
@@ -173,9 +276,13 @@ def read_tpxheader(data):
     bF = data.unpack_int()  # has force or not
     bBox = data.unpack_int()  # has box or not
 
+    sizeOfTprBody = None
+    if fileVersion >= S.tpxv_AddSizeField and fileGeneration >= 27:
+        sizeOfTprBody = data.unpack_int64()
+
     th = obj.TpxHeader(ver_str, precision, fileVersion, fileGeneration,
                        file_tag, natoms, ngtc, fep_state, lamb,
-                       bIr, bTop, bX, bV, bF, bBox)
+                       bIr, bTop, bX, bV, bF, bBox, sizeOfTprBody)
     return th
 
 
@@ -322,7 +429,7 @@ def do_symtab(data):
     symtab_nr = data.unpack_int()  # number of symbols
     symtab = []
     for i in range(symtab_nr):
-        j = do_string(data)
+        j = data.do_string()
         symtab.append(j)
     return symtab
 
@@ -552,7 +659,7 @@ def do_iparams(data, functypes, fver):
             data.unpack_real()  # settle.doh
             data.unpack_real()  # settle.dhh
 
-        elif i in [S.F_VSITE2]:
+        elif i in [S.F_VSITE2, S.F_VSITE2FD]:
             data.unpack_real()  # vsite.a
 
         elif i in [S.F_VSITE3, S.F_VSITE3FD, S.F_VSITE3FAD]:
@@ -710,8 +817,8 @@ def do_resinfo(data, symtab, fver, nres):
         resnames = []
         for i in range(nres):
             resnames.append(symtab[data.unpack_int()])
-            # assume the uchar in gmx is 8 byte, seems right
-            data.unpack_fstring(8)
+            data.unpack_int()
+            data.unpack_uchar()
     return resnames
 
 
@@ -720,8 +827,8 @@ def do_atom(data, fver):
     q = data.unpack_real()  # charge
     mB = data.unpack_real()
     qB = data.unpack_real()
-    tp = data.unpack_uint()  # type is a keyword in python
-    typeB = data.unpack_uint()
+    tp = data.unpack_ushort()  # type is a keyword in python
+    typeB = data.unpack_ushort()
     ptype = data.unpack_int()  # regular atom, virtual site or others
     resind = data.unpack_int()  # index of residue
 
@@ -736,6 +843,7 @@ def do_atom(data, fver):
 def do_ilists(data, fver):
     nr = []  # number of ilist
     iatoms = []  # atoms involved in a particular interaction type
+    pos = []
     for j in range(S.F_NRE):  # total number of energies (i.e. interaction types)
         bClear = False
         for k in S.ftupd:
